Class: Aws::SageMakerMetrics::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SageMakerMetrics::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sagemakermetrics/client.rb,
sig/client.rbs
Overview
An API client for SageMakerMetrics. To construct a client, you need to configure a :region and :credentials.
client = Aws::SageMakerMetrics::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetMetricsResponseSuccess, _BatchPutMetricsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_metrics(params = {}) ⇒ Types::BatchGetMetricsResponse
Used to retrieve training metrics from SageMaker.
-
#batch_put_metrics(params = {}) ⇒ Types::BatchPutMetricsResponse
Used to ingest training metrics into SageMaker.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-sagemakermetrics/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
595 596 597 |
# File 'lib/aws-sdk-sagemakermetrics/client.rb', line 595 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
598 599 600 |
# File 'lib/aws-sdk-sagemakermetrics/client.rb', line 598 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_metrics(params = {}) ⇒ Types::BatchGetMetricsResponse
Used to retrieve training metrics from SageMaker.
86 |
# File 'sig/client.rbs', line 86
def batch_get_metrics: (
|
#batch_put_metrics(params = {}) ⇒ Types::BatchPutMetricsResponse
Used to ingest training metrics into SageMaker. These metrics can be visualized in SageMaker Studio.
106 |
# File 'sig/client.rbs', line 106
def batch_put_metrics: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 |
# File 'lib/aws-sdk-sagemakermetrics/client.rb', line 568 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SageMakerMetrics') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sagemakermetrics' context[:gem_version] = '1.49.0' Seahorse::Client::Request.new(handlers, context) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
588 589 590 |
# File 'lib/aws-sdk-sagemakermetrics/client.rb', line 588 def waiter_names [] end |